.. vim: set fileencoding=utf-8 :

.. _rudderlabs.data.apps:

=======================================
 Rudderlabs Data Apps Development Tools
=======================================

This package provides tools to help you develop your own data apps.


Documentation
-------------

.. toctree::
   :maxdepth: 2

   install
   new_data_app_repo
   data_apps_pipelines
   api

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. include:: links.rst
